@@ -1,7 +1,7 @@
 #!/usr/bin/python3
 
 # typedload
-# Copyright (C) 2020 Salvo "LtWorf" Tomaselli
+# Copyright (C) 2020-2024 Salvo "LtWorf" Tomaselli
 #
 # typedload is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
 
 import argparse
 from datetime import datetime
-from enum import Enum
+from uuid import UUID
 import json
 from typing import *
 import urllib.request
@@ -46,75 +46,48 @@ class CommandLine(NamedTuple):
     def get_url(self) -> str:
         if self.username is None and self.project is None:
             username = 'ltworf'
-            project = 'typedload'
+            project = 'relational'
         elif self.username and self.project:
             username = self.username
             project = self.project
         else:
             raise ValueError('Username and project need to be set together')
-        return 'https://api.github.com/repos/%s/%s/releases' % (username, project)
-
-
-class UserTypes(Enum):
-    #FIXME I could not find the documentation of what the other values can be
-    USER = 'User'
-
-
-class AssetState(Enum):
-    #FIXME I could not find the documentation of what the other values can be
-    UPLOADED = 'uploaded'
+        return f'https://codeberg.org/api/v1/repos/{username}/{project}/releases'
 
 
 class User(NamedTuple):
-    login: str
     id: int
-    node_id: str
-    avatar_url: str
-    gravatar_id: str
-    url: str
-    html_url: str
-    followers_url: str
-    following_url: str
-    gists_url: str
-    starred_url: str
-    subscriptions_url: str
-    organizations_url: str
-    repos_url: str
-    received_events_url: str
-    type: UserTypes
-    site_admin: bool
+    login: str
+    email: str
+    created: datetime
+    username: str
 
 
 class Asset(NamedTuple):
-    url: str
     id: int
-    node_id: str
     name: str
-    uploader: User
-    content_type: str
-    state: AssetState
     size: int
     download_count: int
     created_at: datetime
-    updated_at: datetime
+    uuid: UUID
     browser_download_url: str
 
 
 class Release(NamedTuple):
-    url: str
-    assets_url: str
-    upload_url: str
-    html_url: str
     id: int
-    node_id: str
     tag_name: str
-    target_commitish: str
     name: str
+    url: str
+    html_url: str
+    tarball_url: str
+    zipball_url: str
     draft: bool
-    author: User
     prerelease: bool
     created_at: datetime
     published_at: datetime
+    author: User
+
+
     assets: List[Asset]
 
 
@@ -153,15 +126,9 @@ def main():
     args = typedload.load(parser.parse_args(), CommandLine)
     data = get_data(args)
 
-
     # Github returns dates like this "2016-08-23T18:26:00Z", which are not supported by typedload
     # So we make a custom handler for them.
     loader = typedload.dataloader.Loader()
-    loader.handlers.insert(0, (# Make the new handler first so it overrides the current handler for datetime
-        lambda t: t == datetime,
-        lambda l, v, t: datetime.fromisoformat(v[:-1])
-    ))
-
 
     # We know what the API returns so we can load the json into typed data
     typed_data = loader.load(data, List[Release])
