@@ -1,5 +1,5 @@
 # typedload
-# Copyright (C) 2018-2022 Salvo "LtWorf" Tomaselli
+# Copyright (C) 2018-2024 Salvo "LtWorf" Tomaselli
 #
 # typedload is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -30,12 +30,26 @@ class TestChecks(unittest.TestCase):
 
     def test_is_not_required(self):
         if sys.version_info.minor >= 11:
-            from typing import NotRequired
+            from typing import NotRequired, Required
             assert typechecks.is_notrequired(NotRequired[int])
             assert typechecks.is_notrequired(NotRequired[str])
             assert typechecks.is_notrequired(NotRequired[Union[int, str]])
+            assert not typechecks.is_notrequired(Required[int])
+            assert not typechecks.is_notrequired(Required[str])
+            assert not typechecks.is_notrequired(Required[Union[int, str]])
         assert (not typechecks.is_notrequired(None))
 
+    def test_is_required(self):
+        if sys.version_info.minor >= 11:
+            from typing import NotRequired, Required
+            assert typechecks.is_required(Required[int])
+            assert typechecks.is_required(Required[str])
+            assert typechecks.is_required(Required[Union[int, str]])
+            assert not typechecks.is_required(NotRequired[int])
+            assert not typechecks.is_required(NotRequired[str])
+            assert not typechecks.is_required(NotRequired[Union[int, str]])
+        assert (not typechecks.is_required(None))
+
     def test_not_required(self):
         if sys.version_info.minor < 11:
             # Only from 3.11
@@ -43,6 +57,12 @@ class TestChecks(unittest.TestCase):
         from typing import NotRequired
         assert int == typechecks.notrequiredtype(NotRequired[int])
 
+    def test_required(self):
+        if sys.version_info.minor < 11:
+            # Only from 3.11
+            return
+        from typing import Required
+        assert int == typechecks.requiredtype(Required[int])
 
     def test_is_literal(self):
         if sys.version_info.minor >= 8:
