@@ -672,11 +672,14 @@ def _typeddictload(l: Loader, value: Any, type_) -> Any:
     else:
         necessary_fields = fields
 
-    # Resolve the NotRequired stuff
+    # Resolve the NotRequired/Required stuff
     for k, v in type_hints.items():
         if is_notrequired(v):
             type_hints[k] = notrequiredtype(v)
             necessary_fields.discard(k)
+        elif is_required(v):
+            type_hints[k] = requiredtype(v)
+            necessary_fields.add(k)
 
     return _objloader(l, fields, necessary_fields, type_hints, value, type_, True)
 
